<?php

/**
 * @file
 * Contains \Drupal\miniorange_saml\Form\Export.
 */

namespace Drupal\miniorange_saml\Form;

use Drupal\Core\Form\FormBase;
use Drupal\miniorange_saml\MiniorangeSAMLConstants;
use Drupal\miniorange_saml\Utilities;

class CustomCertificate extends FormBase
{
    public function getFormId()
    {
        return 'miniorange_saml_custom';
    }
    public function buildForm(array $form, \Drupal\Core\Form\FormStateInterface $form_state)
    {
        global $base_url;

        Utilities::visual_tour_start($form, $form_state);

        $form['markup_top'] = array(
            '#markup' =>'<div class="mo_saml_table_layout_1"><div class="mo_saml_table_layout mo_saml_container"><h2>Add Custom Certificate</h2><hr>
                         <br><div class="mo_saml_highlight_background_note_1"><b>Note:</b> Available in <a href="' . $base_url . MiniorangeSAMLConstants::LICENSING_TAB_URL .'"> Enterprise</a> version of the module.</div><br>',
        );

        $form['miniorange_saml_private_certificate'] = array(
            '#type' => 'textarea',
            '#title' => t('X.509 Private Certificate'),
            '#cols' => 1,
            '#rows' => 6,
            '#attributes' => array(
                'style' => 'width:700px; background-color: hsla(0,0%,0%,0.08) !important;',
                'placeholder' => 'Copy and Paste the content from the downloaded certificate or copy the content enclosed in X509Certificate tag (has parent tag KeyDescriptor use=signing) in IdP-Metadata XML file.'
            ),
            '#disabled' => TRUE,
            '#description'=> '<strong>NOTE :</strong> Format of the Private key:<br /><strong>-----BEGIN PRIVATE KEY-----<br />
                  XXXXXXXXXXXXXXXXXXXXXXXXXXX<br />-----END PRIVATE KEY-----</strong><br /><br />',
        );

        $form['miniorange_saml_publ_certificate'] = array(
            '#type' => 'textarea',
            '#title' => t('X.509 Public Certificate '),
            '#cols' => 1,
            '#rows' => 6,
            '#attributes' => array(
                'style' => 'width:700px; background-color: hsla(0,0%,0%,0.08) !important;',
                'placeholder' => 'Copy and Paste the content from the downloaded certificate or copy the content enclosed in X509Certificate tag (has parent tag KeyDescriptor use=signing) in IdP-Metadata XML file.'
            ),
            '#disabled' => TRUE,
            '#description'=> '<strong>NOTE :</strong> Format of the certificate:<br /><strong>-----BEGIN CERTIFICATE-----<br />
                  XXXXXXXXXXXXXXXXXXXXXXXXXXX<br />-----END CERTIFICATE-----</strong><br /><br />',
        );

        $form['save_config_elements'] = array(
            '#type' => 'submit',
            '#name'=>'submit',
            '#value' => t('Upload'),
            '#prefix' => '<td>',
            '#suffix' => '</td>',
            '#submit' => array('::submitForm'),
            '#disabled' => TRUE,
        );

        $form['save_config_elements1'] = array(
            '#type' => 'submit',
            '#value' => t('Reset'),
            '#prefix' => '<td>',
            '#suffix' => '</td></div>',
            '#disabled' => TRUE,
        );

        Utilities::spConfigGuide($form, $form_state);

        $form['markup_bottom'] = array(
            '#markup' =>'<div class="mo_saml_table_layout mo_saml_container"><h2>Generate Custom Certificate</h2><hr><br>
                         <div class="mo_saml_highlight_background_note_1"><b>Note:</b> Available in
                         <a href="' . $base_url . MiniorangeSAMLConstants::LICENSING_TAB_URL .'"> Enterprise</a> version of the module.</div>
                         <br>',
        );

        $form['mo_saml_country_code_text'] = array(
            '#type' => 'textfield',
            '#title' => 'Country Code:',
            '#description' => t('<b>Note: </b>Check your country code <a>here.</a>'),
            '#attributes' => array(
                'style' => 'width:700px; background-color: hsla(0,0%,0%,0.08) !important;',
                'placeholder' => 'Enter Country code'
            ),
            '#disabled' => TRUE,
        );

        $form['mo_saml_certificate_state_name'] = array(
            '#type' => 'textfield',
            '#title' => 'State:',
            '#attributes' => array(
                'style' => 'width:700px; margin-bottom:12px; background-color: hsla(0,0%,0%,0.08) !important;',
                'placeholder' => 'State Name'
            ),
            '#disabled' => TRUE,
        );

        $form['mo_saml_certificate_company_name'] = array(
            '#type' => 'textfield',
            '#title' => 'Company:',
            '#attributes' => array(
                'style' => 'width:700px; margin-bottom:12px; background-color: hsla(0,0%,0%,0.08) !important;',
                'placeholder' => 'Company Name'
            ),
            '#disabled' => TRUE,
        );

        $form['miniorange_saml_unit_name'] = array(
            '#type' => 'textfield',
            '#title' => 'Unit:',
            '#attributes' => array(
                'style' => 'width:700px; margin-bottom:12px; background-color: hsla(0,0%,0%,0.08) !important;',
                'placeholder' => 'Unit name'
            ),
            '#disabled' => TRUE,
        );

        $form['mo_saml_certificate_common_name'] = array(
            '#type' => 'textfield',
            '#title' => 'Common:',
            '#attributes' => array(
                'style' => 'width:700px; margin-bottom:12px; background-color: hsla(0,0%,0%,0.08) !important;',
                'placeholder' => 'Common Name'
            ),
            '#disabled' => TRUE,
        );

        $form['mo_saml_select_digest_algo'] = array(
            '#type' => 'select',
            '#title' => 'Digest Algorithm:',
            '#options' => array(
                'sha512' => t('SHA512'),
                'sha384' => t('SHA384'),
                'sha256' => t('SHA256'),
                'sha1' => t('SHA1'),
            ),
            '#attributes' => array('style' => 'width:700px; margin-bottom:12px;'),
            
        );

        $form['mo_saml_select_private_key_bit'] = array(
            '#type' => 'select',
            '#title' => 'Bits to generate the private key:',
            '#options' => array(
                '2048' => t('2048 bits'),
                '1024' => t('1024 bits'),
            ),
            '#attributes' => array('style' => 'width:700px; margin-bottom:12px;'),
            
        );

        $form['mo_saml_select_valid_days'] = array(
            '#type' => 'select',
            '#title' => 'Valid Days:',
            '#options' => array(
                '365' => t('365 days'),
                '180' => t('180 days'),
                '90' => t('90 days'),
                '45' => t('45 days'),
                '30' => t('30 days'),
                '15' => t('15 days'),
                '7' => t('7 days'),
            ),
            '#attributes' => array('style' => 'width:700px; margin-bottom:12px;'),
            
            '#suffix' => '</td></tr></table>',
        );

        $form['generate_config_elements'] = array(
            '#type' => 'submit',
            '#value' => t('Generate Self-Signed Certs'),
            '#prefix' => '<td><br><br>',
            '#submit' => array('::miniorange_saml_generate_custom_certificate'),
            '#disabled' => TRUE,
        );

        $form['clear_genrate_certificate_data'] = array(
            '#type' => 'submit',
            '#value' => t('Clear Data'),
            '#submit' => array('::miniorange_saml_clear_genrate_certificate_data'),
            '#suffix' => '</td><br><br><br></div>',
            '#disabled' => TRUE,
        );

        Utilities::AddSupportButton($form, $form_state);

        return $form;
    }

    public function submitForm(array &$form, \Drupal\Core\Form\FormStateInterface $form_state)
    {

    }

}