<?php
/**
 * @file
 * Contains Attribute and Role Mapping for miniOrange SAML Login Module.
 */

 /**
 * Showing Settings form.
 */
namespace Drupal\miniorange_saml\Form;

use Drupal\Core\Form\FormBase;
use Drupal\miniorange_saml\Utilities;
use Drupal\miniorange_saml\MiniorangeSAMLConstants;

class Mapping extends FormBase {
	 
  public function getFormId() {
    return 'miniorange_saml_mapping';
  }
	 
 public function buildForm(array $form, \Drupal\Core\Form\FormStateInterface $form_state) {

  global $base_url;

     Utilities::visual_tour_start($form, $form_state);

     $form['markup_top'] = array(
         '#markup' => '<div class="mo_saml_table_layout_1"><div class="mo_saml_table_layout mo_saml_container" >
                       <h2 ><span >Attribute Mapping (Optional) </span>
                       <a id="Restart_moTour" class="btn btn-primary btn-sm mo_tour_button_float" onclick="Restart_moTour()">Take a Tour</a></h2><hr><br>'
     );

     $form['Configure_Attribute_Mapping_End'] = array(
         '#markup' => '<div id="configure_attribute_mapping_start"></div><div class="mo_saml_highlight_background_note_1" ><b>Note: <code>Username Attribute</code> </b> and <b><code>Email Attribute</code></b> are configurable in 
                 <a href="' . $base_url . MiniorangeSAMLConstants::LICENSING_TAB_URL .'">Standard, Premium and Enterprise</a> versions of the module.</div>',
     );

      $form['miniorange_saml_username_attribute'] = array(
        '#type' => 'textfield',
        '#title' => t('Username Attribute'),
        '#default_value' => \Drupal::config('miniorange_saml.settings')->get('miniorange_saml_username_attribute'),
        '#attributes' => array('style' => 'width:700px; background-color: hsla(0,0%,0%,0.08) !important;','placeholder' => 'Enter Username attribute'),
        '#disabled' => TRUE,
      );

      $form['miniorange_saml_email_attribute'] = array(
          '#type' => 'textfield',
          '#title' => t('Email Attribute'),
          '#default_value' => \Drupal::config('miniorange_saml.settings')->get('miniorange_saml_email_attribute'),
          '#attributes' => array('style' => 'width:700px; background-color: hsla(0,0%,0%,0.08) !important;','placeholder' => 'Enter Email attribute'),
          '#disabled' => TRUE,
      );

     $form['miniorange_saml_gateway_config1_submit'] = array(
         '#type' => 'submit',
         '#value' => t('Save Configuration'),
         '#prefix' => '<br>',
         '#suffix' => '<br><br>',
         '#disabled'=>TRUE,
     );

     $form['miniorange_saml_enable_rolemapping'] = array(
         '#type' => 'checkbox',
         '#title' => t('Check this option if you want to <b>enable Role Mapping</b>'),
         '#default_value' => \Drupal::config('miniorange_saml.settings')->get('miniorange_saml_enable_rolemapping'),
         '#attributes' => array('class="mo_saml_checkbox"'),
         '#description' => t('<b style="color: red">Note:</b> Enable this checkbox first before using any of the feature below.'),
         '#prefix' => '<br><br><div id="Enable_Rolemapping"><h2>Role Mapping</h2><hr><br>',
         '#suffix' => '</div>',
     );

     $mrole = user_role_names(TRUE);
     $default_role_index = \Drupal::configFactory()->getEditable('miniorange_saml.settings')->get('miniorange_saml_default_role_index');

     $form['miniorange_saml_default_mapping'] = array(
         '#type' => 'select',
         '#title' => t('Select default group for the new users'),
         '#options' => array_values($mrole),
         '#description'=>t('<strong>Note: </strong>This role will be assigned to user when he uses SSO for the first time. (<em> at the time of user creation in Drupal site </em>)'),
         '#default_value' => $default_role_index,
         '#attributes' => array('style' => 'width:700px;background-image: inherit;background-color: white;-webkit-appearance: menulist;'),
         '#prefix' => '<div id="Default_Mapping">',
         '#suffix' => '</div>',
     );

     $form['miniorange_saml_disable_role_update'] = array(
         '#type' => 'checkbox',
         '#title' => t('Check this option if you do not want to update user role if roles not mapped '),
         '#disabled' => TRUE,
         '#description'=>t('<b>Note:</b> This feature is availabe in <a href="' . $base_url . MiniorangeSAMLConstants::LICENSING_TAB_URL .'">Premium and Enterprise</a> versions of the module.'),
         '#prefix' => '<div class="mo_saml_highlight_background_note_1">',
     );

     $form['miniorange_saml_gateway_config2_submit'] = array(
         '#type' => 'submit',
         '#value' => t('Save Configuration'),
         '#prefix' => '</div><br>',
         '#suffix' => '<br><br>',
     );

    $form['markup_cam_attr'] = array(
        '#markup' => '<br><div id="mo_saml_attr_mapping_note"><br><h2  >Custom Attribute Mapping </h2><hr><br><div class="mo_saml_highlight_background_note_1"><b>Note: </b>Custom Attribute Mapping is configurable in
            <a href="' . $base_url . MiniorangeSAMLConstants::LICENSING_TAB_URL .'">Standard, Premium and Enterprise</a> versions of the module.</div>',
    );

      $form['markup_cam'] = array(
         '#markup' => '<br><div class="mo_saml_highlight_background_note_1"><p><b>NOTE: </b> Add the Drupal field attributes in the Attribute Name textfield and add the IdP attibutes that you need to map with the drupal attributes in the IdP Attribute Name textfield. 
                                   <br> <b>Attribute Name:</b> It is the user attribute (machine name) whose value you want to set in site.
                                   <br> <b>IdP Attribute Name:</b> It is the name which you want to get from your IDP. It should be unique.</p></div><p><b>For example: If the attribute name in the drupal is name then its machine name will be field_name.</b></p>',
      );

     $form['miniorange_saml_custom_attr_buttons']=array(
          '#markup'=>'<h3 >Add Custom Atrribute <a class="btn btn-large btn-primary">&nbsp;&nbsp;+&nbsp;&nbsp;</a><h3><table class="miniorange_saml_sp_attr_table"><tr><td>SP Attribute</td><td>Idp Attribute</td><td></td></tr>',
          
     );

     $form['user_sp_attr_name'] = array(
          '#prefix'=>'<tr><td>',
          '#type' => 'textfield',
          '#disabled'=>TRUE,
          '#attributes' => array('style' => 'background-color: hsla(0,0%,0%,0.08) !important;'),
          '#suffix'=>'</td>',
      );
     $form['user_idp_attr_name'] = array(
          '#prefix'=>'<td>',
          '#type' => 'textfield',
          '#disabled'=>TRUE,
          '#suffix'=>'</td>',
          '#attributes' => array('style' => 'background-color: hsla(0,0%,0%,0.08) !important;'),

     );
     $form['user_delete'] = array(
          '#prefix'=>'<td><a class="btn btn-danger btn-sm">-</a>',
          '#suffix'=>'</td></tr></table>',
     );
     $form['miniorange_saml_gateway_config3_submit'] = array(
         '#type' => 'submit',
         '#value' => t('Save Configuration'),
         '#disabled' => TRUE,
         '#prefix' => '<br>',
         '#suffix' => '<br></div><br>',
     );

      $form['markup_custom_role_mapping'] = array(
         '#markup' => '<br/><div id="mo_saml_role_mapping_note"><h2>Custom Role Mapping </h2><hr><br><div class="mo_saml_highlight_background_note_1">
                       <b>Note: </b>Custom Role Mapping is configurable in <a href="' . $base_url . MiniorangeSAMLConstants::LICENSING_TAB_URL .'">Premium and Enterprise</a> versions of the module.</div>',
      );

     $form['miniorange_saml_idp_attr1_name'] = array(
         '#type' => 'textfield',
         '#title' => t('Role Key'),
         '#attributes' => array('style' => 'width:700px; background-color: hsla(0,0%,0%,0.08) !important;','placeholder' => 'Enter Role Attribute'),
         '#description' => '<b>Note:</b> You will find role key value in the test configuration window.<br><br>',
         '#disabled' => TRUE,
     );

      $form['miniorange_saml_custom_role_buttons']=array(
          '#markup'=>'<h3 >Add Custom Role Mapping <a class="btn btn-large btn-primary">&nbsp;&nbsp;+&nbsp;&nbsp;</a><h3><table class="miniorange_saml_sp_attr_table"><tr><td>SP Role</td><td>Idp Role</td><td></td></tr>',
          
     );

     $form['user_sp_role_name'] = array(
          '#prefix'=>'<tr><td>',
          '#type' => 'select',
          '#options'=>$mrole,
          '#attributes'=>array('style'=>'width:100%;'),
          '#suffix'=>'</td>',
      );
     $form['user_idp_role_name'] = array(
          '#prefix'=>'<td>',
          '#type' => 'textfield',
          '#suffix'=>'</td>',
          '#attributes' => array('style' => 'background-color: hsla(0,0%,0%,0.08) !important;'),
          '#disabled'=>TRUE,
     );
     $form['user_role_delete'] = array(
          '#prefix'=>'<td><a class="btn btn-danger btn-sm">-</a>',
          '#suffix'=>'</td></tr></table>',
     );

      $form['miniorange_saml_gateway_config4_submit'] = array(
          '#type' => 'submit',
          '#value' => t('Save Configuration'),
          '#disabled' => TRUE,
          '#prefix' => '<br>',
          '#suffix' => '<br><br></div></div>',
      );

     Utilities::spConfigGuide($form, $form_state);

     Utilities::AddSupportButton($form, $form_state);

     return $form;

 }

    public function submitForm(array &$form, \Drupal\Core\Form\FormStateInterface $form_state) {

        $username_attribute = $form['miniorange_saml_username_attribute']['#value'];
        $email_attribute = $form['miniorange_saml_email_attribute']['#value'];
        $enable_rolemapping = $form['miniorange_saml_enable_rolemapping']['#value'];
        $default_mapping = $form['miniorange_saml_default_mapping']['#value'];

        $i = 0;
        $mrole = user_role_names(TRUE );
        foreach( $mrole as $key => $value ) {
            $def_role[$i] = $value;
            $i++;
        }

        $enable_rolemapping_value = $enable_rolemapping == 1 ? TRUE : FALSE;

        if( $enable_rolemapping_value ) {
            \Drupal::configFactory()->getEditable('miniorange_saml.settings')->set('miniorange_saml_default_role', $def_role[$default_mapping]);
            \Drupal::configFactory()->getEditable('miniorange_saml.settings')->set('miniorange_saml_default_role_index', $default_mapping);
        }else {
            \Drupal::configFactory()->getEditable('miniorange_saml.settings')->set('miniorange_saml_default_role', $mrole['authenticated'])->save();
        }

        \Drupal::configFactory()->getEditable('miniorange_saml.settings')->set('miniorange_saml_username_attribute', $username_attribute)->save();
        \Drupal::configFactory()->getEditable('miniorange_saml.settings')->set('miniorange_saml_email_attribute', $email_attribute)->save();
        \Drupal::configFactory()->getEditable('miniorange_saml.settings')->set('miniorange_saml_enable_rolemapping', $enable_rolemapping_value)->save();
        \Drupal::messenger()->addMessage(t('Mapping Settings successfully saved'), 'status');
    }
  }