<?php

/**
 * @file
 * Contains \Drupal\miniorange_saml\Form\MiniorangeIDPSetup.
 */

namespace Drupal\miniorange_saml\Form;

use Drupal\Core\Form\FormBase;
use Drupal\miniorange_saml\Utilities;
use Drupal\miniorange_saml\MiniorangeSAMLConstants;

class MiniorangeIDPSetup extends FormBase {

    public function getFormId() {
        return 'miniorange_saml_idp_setup';
    }

    public function buildForm(array $form, \Drupal\Core\Form\FormStateInterface $form_state) {

        global $base_url;
        $module_path = drupal_get_path('module', 'miniorange_saml');

        Utilities::visual_tour_start($form, $form_state);

        $acs_url = $base_url . '/samlassertion';

        $form['miniorange_saml_tour_button'] = array(
            '#attached' => array(
                'library' => array(
                    'miniorange_saml/miniorange_saml.Vtour',
                    'miniorange_saml/miniorange_saml_copy.icon',
                )
            ),
            '#markup' => '<div><h2>Service Provider Metadata &nbsp; <a id="Restart_moTour" class="btn btn-primary btn-sm mo_tour_button_float" onclick="Restart_moTour()">Take a Tour</a></h2><hr></div><br>',
            '#prefix' => '<div class="mo_saml_table_layout_1"><div class="mo_saml_table_layout mo_saml_container">',
        );

        $form['miniorange_saml_update_url_note'] = array(
            '#markup'=>'<div class="mo_saml_highlight_background_note_1"><strong>Note: </strong> If you have already shared the below URLs or Metadata with your IdP, <strong>DO NOT UPDATE</strong> SP EntityID. It might break your existing login flow.
                         Available in the <a href="' . $base_url . MiniorangeSAMLConstants::LICENSING_TAB_URL .'">Standard, Premium and Enterprise</a> version.   </div><br>'
        );

        $form['miniorange_saml_base_url'] = array(
            '#type' => 'textfield',
            '#title' => t('SP Base URL:'),
            '#default_value' => $base_url,
            '#attributes' => array('style' => 'width:700px'),
            '#disabled' => TRUE,
        );

        $form['miniorange_saml_entity_id'] = array(
            '#type' => 'textfield',
            '#title' => t('SP Entity ID/Issuer:'),
            '#default_value' => $base_url,
            '#attributes' => array('style' => 'width:700px'),
            '#disabled' => TRUE,
        );

        $form['miniorange_saml_idp_config_submit'] = array(
            '#type' => 'submit',
            '#value' => t('Update'),
            '#disabled' => TRUE,
            '#suffix' => '<br><br><hr>'
        );


        $form['mo_saml_metadata_option'] = array(
            '#markup' => '<br><div class="mo_text_color"><b>Provide this module information to your Identity Provider team. You can choose any one of the below options:</b></div>
                          <br><b>a) Provide this metadata URL to your Identity Provider:</b><br>',
        );

        $form['markup_idp_sp_2'] = array(
            '#markup' => '<div>
                            <div class="mo_saml_highlight_background_url_note" id="idp_metadata_url">
                                <code><b>
                                    <span>
                                        <a target="_blank" href="' . $base_url . '/saml_metadata">' . $base_url . '/saml_metadata' . '</a>
                                    </span></b>
                                </code>
                            </div>
                            <img class ="fa fa-fw fa-lg fa-copy mo_copy mo-margin" src="'. $base_url.'/'.$module_path . '/includes/images/copy-regular.svg">
                        </div>',
        );

        $form['mo_saml_download_btn_title'] = array(
            '#markup' => '<br><br><div id="download_metadata_xml_file"><b>b) Download the Module XML metadata and upload it on your Identity Provider : </b>
                        <span><a href="' . $base_url . '/saml_metadata?download=true" class="btn btn-danger btn-sm">Download XML Metadata</a></span></div>
                        <br><br><div><b>c) Provide the following information to your Identity Provider. Copy it and keep it handy.</b></div><br>',
        );

        $form['mo_saml_attrs_list_idp'] = array(
            '#markup' => '<div class="table-responsive" style="font-family: sans-serif;font-size: 12px;" id="mo_idp_vt_conf_table">   
                <table class="mo_guide_table mo_guide_table-striped mo_copy_icon_not_center" style="border: 1px solid #ddd;max-width: 100%;border-collapse: collapse;">
                    <thead>
                        <tr>
                            <th class="mo_guide_text-center mo_td_values">ATTRIBUTE</th>
                            <th class="mo_guide_text-center mo_td_values">VALUE</th>   
                            <tbody style="font-size: 12px;color:gray;">     
                                <tr>
                                    <td style="font-weight:bold;padding: 15px;">SP Entity ID/Issuer</td>
                                    <td>						               
						               <span id="issuer_id">' . $base_url . '</span>						                 
                                       <img class ="fa fa-fw fa-pull-right fa-lg fa-copy mo_copy" src="'. $base_url.'/'.$module_path . '/includes/images/copy-regular.svg">			
						            </td>                                    
                                </tr>                                
                                <tr>
                                    <td style="font-weight:bold;padding: 15px;">SP ACS URL</td>
                                    <td>						               
						               <span id="login_url">' . $acs_url . '</span>						                 
                                       <img class ="fa fa-fw fa-pull-right fa-lg fa-copy mo_copy" src="'. $base_url.'/'.$module_path . '/includes/images/copy-regular.svg">			
						            </td>                                    
                                </tr>
                                <tr>
                                    <td style="font-weight:bold;padding: 15px;">Audience URI</td>
                                    <td>						               
						               <span id="audience_url">' . $base_url . '</span>						                 
                                       <img class ="fa fa-fw fa-pull-right fa-lg fa-copy mo_copy" src="'. $base_url.'/'.$module_path . '/includes/images/copy-regular.svg">			
						            </td>                                    
                                </tr>
                                <tr>
                                    <td style="font-weight:bold;padding: 15px;">Recipient URL</td>
                                    <td>						               
						               <span id="recipientURL">' . $acs_url . '</span>						                 
                                       <img class ="fa fa-fw fa-pull-right fa-lg fa-copy mo_copy" src="'. $base_url.'/'.$module_path . '/includes/images/copy-regular.svg">			
						            </td>                                    
                                </tr>
                                <tr>
                                    <td style="font-weight:bold;padding: 15px;">Destination URL</td>
                                    <td>						               
						               <span id="destinationURL">' . $acs_url . '</span>						                 
                                       <img class ="fa fa-fw fa-pull-right fa-lg fa-copy mo_copy" src="'. $base_url.'/'.$module_path . '/includes/images/copy-regular.svg">			
						            </td>                                    
                                </tr>
                                <tr>
                                    <td style="font-weight:bold;padding: 15px;">Single Logout URL</td>
                                    <td>						               
						               Available in </b><a href="' . $base_url . MiniorangeSAMLConstants::LICENSING_TAB_URL .'">Premium and Enterprise</a> version.		
						            </td>                                    
                                </tr>  
                                <tr>
                                    <td style="font-weight:bold;padding: 15px;">NameID Format</td>
                                    <td>						               
						               urn:oasis:names:tc:SAML:1.1:nameid-format:unspecified		
						            </td>                                    
                                </tr>                                                                                                                                                                                                                  
                            </tbody>                                                 
                        </tr>
                    </thead>
                    </table>
          </div></div>'
        );

        Utilities::spConfigGuide($form, $form_state);
        Utilities::AddSupportButton($form, $form_state);

        return $form;
    }

    public function submitForm(array &$form, \Drupal\Core\Form\FormStateInterface $form_state) {

    }
}