<?php

/**
 * @file
 * Contains \Drupal\miniorange_saml\Form\MiniorangeSPInformation.
 */

namespace Drupal\miniorange_saml\Form;

use Drupal\Core\Form\FormBase;
use Drupal\miniorange_saml\MiniorangeSAMLConstants;
use Drupal\miniorange_saml\Utilities;
use Drupal\miniorange_saml\MetadataReader;

class MiniorangeSPInformation extends FormBase {
    /**
    * {@inheritdoc}
    */
    public function getFormId() {
        return 'miniorange_sp_setup';
    }

    public function buildForm(array $form, \Drupal\Core\Form\FormStateInterface $form_state) {
        global $base_url;

        $form['markup_library'] = array(
            '#attached' => array(
                'library' => array(
                    "miniorange_saml/miniorange_saml.test",
                    "miniorange_saml/miniorange_saml.admin",
                )
            )
        );

        Utilities::visual_tour_start($form, $form_state);

        $form['miniorange_saml_IDP_tab'] = array(
            '#markup' => '<div class="mo_saml_table_layout_1"><div class="mo_saml_table_layout mo_saml_container"><div ><h5 > <span id="tabhead">Enter the information gathered from your Identity Provider &nbsp; OR &nbsp;&nbsp;
                            <a id="showMetaButton" class="btn btn-primary btn-sm" onclick="testConfig()">Upload IDP Metadata</a>&nbsp;&nbsp;&nbsp;&nbsp;</span>
                                <a id="Restart_moTour" class="btn btn-primary btn-sm mo_tour_button_float" onclick="Restart_moTour()">Take a Tour</a><br><br><hr><hr></h5></div>',
        );

        $form['metadata_1'] = array(
            '#markup' =>'<div border="1" id="upload_metadata_form" class="mo_saml_meta_upload">
				<h3>UPLOAD IDP METADATA</h3><hr><br><span class="mo_saml_cancel_upload">
				<a id="hideMetaButton" class="btn btn-sm btn-danger" onclick = "testConfig()">Cancel</a></span>',
        );

        $form['metadata_file'] = array(
            '#type' => 'file',
            '#title' => t('Upload Metadata File:'),
        );
  
        $form['metadata_upload'] = array(
            '#type' => 'submit',
            '#value' => t('Upload File'),
            '#submit' => array('::miniorange_saml_upload_file'),
            '#suffix'  => '<br><br><h2>&emsp;&emsp;&emsp;&emsp; OR</h2><br>',
        );
  
        $form['metadata_URL'] = array(
            '#type' => 'textfield',
            '#title' => t('Upload Metadata URL:'),
	        '#attributes' => array('style' => 'width:77%','placeholder' => 'Enter metadata URL of your IdP.'),
        );

        $form['metadata_fetch'] = array(
            '#type' => 'submit',
            '#value' => t('Fetch Metadata'),
            '#submit' => array('::miniorange_saml_fetch_metadata'),
            '#suffix' => '<br><br>',
        );

        $form['miniorange_saml_fetch_metadata_1'] = array(
            '#type' => 'checkbox',
            '#title' => t('Update IdP settings by pinging metadata URL (We will store the metadata URL). <a href="' . $base_url . MiniorangeSAMLConstants::LICENSING_TAB_URL .'">[Premium and Enterprise]</a>'),
            '#disabled' => TRUE,
        );

        $form['metadata_fetch_1'] = array(
            '#markup' => '<div class="mo_saml_highlight_background_note_1"><b>Note: </b>You can set how often you want to ping the IdP from <b><a target="_blank" href="' . $base_url . '/admin/config/system/cron "> Here</a> OR </b> you can goto <b>Configuration=>Cron=>Run Cron Every</b> section of your drupal site.</div><br>',
            '#suffix' => '<hr></div><div id="idpdata">',
        );

        $form['miniorange_saml_idp_name'] = array(
            '#type' => 'textfield',
            '#title' => t('Identity Provider Name<span style="color: #FF0000">*</span>'),
            '#default_value' => \Drupal::config('miniorange_saml.settings')->get('miniorange_saml_idp_name'),
            '#attributes' => array('style' => 'width:700px;', 'placeholder' => 'Identity Provider Name'),
            '#prefix' =>'<div id = "miniorange_saml_idp_name_div">',
            '#suffix' =>'</div>',
        );

        $form['miniorange_saml_idp_issuer'] = array(
            '#type' => 'textfield',
            '#title' => t('IdP Entity ID or Issuer<span style="color: #FF0000">*</span>'),
            '#default_value' => \Drupal::config('miniorange_saml.settings')->get('miniorange_saml_idp_issuer'),
            '#attributes' => array('style' => 'width:700px;','placeholder' => 'IdP Entity ID or Issuer'),
	        '#description' => t('<b>Note: </b>You can find the EntityID in Your IdP-Metadata XML file enclosed in <code>EntityDescriptor</code> tag having<br> attribute as <code>entityID</code>'),
            '#prefix' =>'<div id = "miniorange_saml_idp_issuer_div">',
            '#suffix' =>'</div>',
        );

        $form['miniorange_saml_idp_login_url'] = array(
            '#type' => 'textfield',
            '#title' => t('SAML Login URL<span style="color: #FF0000">*</span>'),
            '#default_value' => \Drupal::config('miniorange_saml.settings')->get('miniorange_saml_idp_login_url'),
            '#description' => t('<b>Note: </b>You can find the SAML Login URL in Your IdP-Metadata XML file enclosed in <code>SingleSignOnService</code><br> tag'),
            '#attributes' => array('style' => 'width:700px;', 'placeholder' => 'SAML Login URL'),
            '#prefix' =>'<div id="miniorange_saml_idp_login_url_start">',
            '#suffix' =>'</div>',
        );

        $form['miniorange_saml_nameid_format'] = array(
            '#type' => 'select',
            '#title' => t('NameID Format <a href="' . $base_url . MiniorangeSAMLConstants::LICENSING_TAB_URL .'"> <b>[Premium]</b></a>'),
            '#options' => array('nameid-format' => t('urn:oasis:names:tc:SAML:1.1:nameid-format:unspecified'),),
            '#attributes' => array('style' => 'width:700px;'),
            '#description' => t('<b>Note: </b>This feature is available in the premium version of the module.'),
            '#disabled' => TRUE,
        );

        $form['miniorange_saml_idp_logout_url'] = array(
            '#type' => 'textfield',
            '#title' => t('SAML Logout URL <a href="' . $base_url . MiniorangeSAMLConstants::LICENSING_TAB_URL .'"> <b>[Premium]</b></a>'),
            '#description' => t('<b>Note: </b>This feature is available in the premium version of the module.'),
            '#attributes' => array('style' => 'width:700px; background-color: hsla(0,0%,0%,0.08) !important;', 'placeholder' => 'SAML Logout URL'),
            '#disabled' => TRUE,
        );

        $form['myradios'] = array(
            '#title' => t('x.509 Certificate Value'),
            '#type' => 'radios',
            '#options' => array(
                'text' => 'Enter as Text',
                'upload' => 'Upload Certificate',
            ),
            '#default_value' => 'text',
            '#prefix' => '<br>',
            '#suffix' => '<br><div id="miniorange_saml_idp_x509_certificate_start">',
        );

        $form['miniorange_saml_idp_x509_certificate'] = array(
            '#type' => 'textarea',
            '#cols' => '10',
            '#rows' => '5',
            '#default_value' => \Drupal::config('miniorange_saml.settings')->get('miniorange_saml_idp_x509_certificate'),
            '#attributes' => array('style' => 'width:700px;','placeholder' => 'Enter x509 Certificate Value'),
            '#description'=>t('<b>NOTE: </b>Format of the certificate:<br><b>-----BEGIN CERTIFICATE-----<br>XXXXXXXXXXXXXXXXXXXXXXXXXXX<br>-----END CERTIFICATE-----</b><br><br>'),
            '#suffix' => '</div>',
        );

        $form['mo_saml_cert_file'] = array(
            '#type' => 'file',
            '#title' => 'Upload Certificate',
            '#attributes' => array('style' => 'float: left;'),
            '#prefix' => '<div id="mo_saml_file" class="mo_saml_hidden">',
        );

        $form['metadata_upload_cert_file'] = array(
            '#type' => 'submit',
            '#value' => t('Upload'),
            '#submit' => array('::mo_saml_upload_certificate'),
            '#attributes' => array('style' => 'margin-top: -5px;'),
            '#suffix' => '</div><br>',
        );

        $form['miniorange_saml_enable_login'] = array(
            '#type' => 'checkbox',
            '#title' => t('Enable login with SAML'),
            '#default_value' => \Drupal::config('miniorange_saml.settings')->get('miniorange_saml_enable_login'),
            '#prefix' => '<div id="enable_login_with_saml">',
            '#suffix' => '</div>'
        );

        $form['security_signature_algorithm'] = array(
            '#type' => 'select',
            '#title' => t('Signature algorithm <a href="' . $base_url . MiniorangeSAMLConstants::LICENSING_TAB_URL .'"> <b>[Enterprise]</b></a>'),
            '#options' => ['RSA_SHA256' => 'sha256'],
            '#description' => t('<b>Note:</b> Algorithm used in the signing process. (Algorithm eg. sha256, sha384, sha512, sha1 etc)'),
            '#attributes' => array('style' => 'width: 50%'),
            '#disabled' => TRUE,
        );

        $form['miniorange_saml_sign_request'] = array(
            '#type' => 'checkbox',
            '#title' => t('Check this option to send Signed SSO and SLO requests.<a href="' . $base_url . MiniorangeSAMLConstants::LICENSING_TAB_URL .'"> [Standard, Premium and Enterprise].</a>'),
            '#disabled' => TRUE,
            '#prefix' => '<div class="mo_saml_highlight_background_note_1">',
            '#suffix' => '</div><br><br>',
        );

        $form['miniorange_saml_idp_config_submit'] = array(
            '#type' => 'submit',
            '#value' => t('Save Configuration'),
        );

        $form['miniorange_saml_test_config_button'] = array(
	        '#attached' => array ('library' => 'miniorange_saml/miniorange_saml.test',),
            '#markup' => '<a id="testConfigButton" class="btn btn-success btn-sm" onclick="testConfig();">Test Configuration</a>'
        );

        $form['miniorange_saml_test_show_SAML_request_button'] = array(
	        '#attached' => array(
	            'library' => 'miniorange_saml/miniorange_saml.button',
	        ),
            '#markup' => '<br><br>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;<a id="showSAMLrequestButton" class="btn btn-primary btn-sm mo_btn_style" onclick="showSAMLRequest();">Show SAML Request</a>&nbsp;&nbsp;&nbsp;'
        );

        $form['miniorange_saml_test_show_SAML_response_button'] = array(
            '#attached' => array(
                'library' => 'miniorange_saml/miniorange_saml.button',
            ),
            '#markup' => '&nbsp;&nbsp;&nbsp;<a id="showSAMLresponseButton" class="btn btn-primary btn-sm" onclick="showSAMLResponse();">Show SAML Response</a>',
            '#suffix' => '</div><br><br></div>',
        );

        Utilities::spConfigGuide($form, $form_state);
        Utilities::AddSupportButton($form, $form_state);

        return $form;
    }

    public function miniorange_saml_form_alter(array &$form, \Drupal\Core\Form\FormStateInterface $form_state, $form_id){
        $form['actions']['submit']['#submit'][] = 'test';
	    return $form;
	}

    function mo_saml_upload_certificate(array &$form, \Drupal\Core\Form\FormStateInterface $form_state) {

        $certificate = $_FILES['files']['tmp_name']['mo_saml_cert_file'];
        if( !empty( $certificate ) ) {
            $file_name = $_FILES['files']['name']['mo_saml_cert_file'];
            list($name_without_extention, $extention) = explode('.', $file_name);
            if($extention == 'crt' || $extention == 'cer' || $extention == 'cert')  {

                $cert_content = Utilities::sanitize_certificate( file_get_contents( $certificate ) );
                $idp_name = $form['miniorange_saml_idp_name']['#value'];
                $issuer = $form['miniorange_saml_idp_issuer']['#value'];
                $login_url = $form['miniorange_saml_idp_login_url']['#value'];
                \Drupal::configFactory()->getEditable('miniorange_saml.settings')->set('miniorange_saml_idp_name', $idp_name)->save();
                \Drupal::configFactory()->getEditable('miniorange_saml.settings')->set('miniorange_saml_idp_issuer', str_replace(' ', '', $issuer))->save();
                \Drupal::configFactory()->getEditable('miniorange_saml.settings')->set('miniorange_saml_idp_login_url', str_replace(' ', '', $login_url))->save();
                \Drupal::configFactory()->getEditable('miniorange_saml.settings')->set('miniorange_saml_idp_x509_certificate', $cert_content)->save();
                \Drupal::messenger()->addMessage(t('x.509 Certificate Value successfully updated.'));
                return;
            }else {
                \Drupal::messenger()->addMessage(t('<b style="color: red">File type is not compatible</b> <br> Please Select <b style="color: red">".crt"</b>  or <b style="color: red">".cert"</b> extended file to upload Configuration!'),'error');
                return;
            }
        }else {
            \Drupal::messenger()->addMessage(t('<b style="color: red">Please select file first to upload Configuration!</b>'),'error');
            return;
        }
    }

    /**
    * Configure IdP.
    */
    public function submitForm(array &$form, \Drupal\Core\Form\FormStateInterface $form_state) {
        global $base_url;
        $issuer = $form['miniorange_saml_idp_issuer']['#value'];
        $idp_name = $form['miniorange_saml_idp_name']['#value'];
        $nameid_format = 'urn:oasis:names:tc:SAML:1.1:nameid-format:unspecified';
        $login_url = $form['miniorange_saml_idp_login_url']['#value'];
        $x509_cert_value = Utilities::sanitize_certificate($form['miniorange_saml_idp_x509_certificate']['#value']);
        $enable_login_value = $form['miniorange_saml_enable_login']['#value'];

        if( empty( $idp_name ) || empty( $issuer ) || empty( $login_url ) ){
            \Drupal::messenger()->addMessage(t('The <b><u>Identity Provider Name, IdP Entity ID or Issuer</u></b> and <b><u>SAML Login URL</u></b> fields are mandatory.'), 'error');
            return;
        }

        $enable_login = $enable_login_value == 1 ? TRUE : FALSE;

        $sp_issuer = $base_url . '/samlassertion';

        \Drupal::configFactory()->getEditable('miniorange_saml.settings')->set('miniorange_saml_base', $base_url)->save();
        \Drupal::configFactory()->getEditable('miniorange_saml.settings')->set('miniorange_saml_idp_name', $idp_name)->save();
        \Drupal::configFactory()->getEditable('miniorange_saml.settings')->set('miniorange_saml_sp_issuer', $sp_issuer)->save();
        \Drupal::configFactory()->getEditable('miniorange_saml.settings')->set('miniorange_saml_idp_issuer', str_replace(' ', '', $issuer))->save();
        \Drupal::configFactory()->getEditable('miniorange_saml.settings')->set('miniorange_saml_nameid_format', $nameid_format)->save();
        \Drupal::configFactory()->getEditable('miniorange_saml.settings')->set('miniorange_saml_idp_login_url', str_replace(' ', '', $login_url))->save();
        \Drupal::configFactory()->getEditable('miniorange_saml.settings')->set('miniorange_saml_idp_x509_certificate', $x509_cert_value)->save();
        \Drupal::configFactory()->getEditable('miniorange_saml.settings')->set('miniorange_saml_enable_login', $enable_login)->save();

        \Drupal::messenger()->addMessage(t('Identity Provider Configuration successfully saved'),'status');
    }

    function miniorange_saml_upload_file(array &$form, \Drupal\Core\Form\FormStateInterface $form_state) {
    	$file_name = $_FILES['files']['tmp_name']['metadata_file'];
    	if( empty( $file_name ) ) {
            \Drupal::messenger()->addMessage(t('Please Provider valid metadata file.'),'error');
            return;
        }
    	$file = file_get_contents( $file_name );
    	self::upload_metadata( $file );
    }

    function miniorange_saml_fetch_metadata(array &$form, \Drupal\Core\Form\FormStateInterface $form_state) {
    	$url = filter_var($form['metadata_URL']['#value'],FILTER_SANITIZE_URL);
        if( empty( $url ) ) {
            \Drupal::messenger()->addMessage(t('Please Provider valid metadata URL.'),'error');
            return;
        }
    	$arrContextOptions = array(
    	    "ssl"=>array(
				"verify_peer"=>false,
				"verify_peer_name"=>false,
            ),
        );
	    $file = file_get_contents( $url, false, stream_context_create( $arrContextOptions ) );
	    self::upload_metadata( $file );
    }

    public function upload_metadata($file){

        global $base_url;
        $idp_name_stored = \Drupal::config('miniorange_saml.settings')->get('miniorange_saml_idp_name');
        if ( empty( $idp_name_stored ) ) {
            \Drupal::configFactory()->getEditable('miniorange_saml.settings')->set('miniorange_saml_idp_name', 'Identity Provider')->save();
        }

    	$document = new \DOMDocument();
		$document->loadXML($file);
		restore_error_handler();
		$first_child = $document->firstChild;

		if( !empty( $first_child ) ) {
			$metadata = new MetadataReader($document);
			$identity_providers = $metadata->getIdentityProviders();
			if( empty( $identity_providers ) ) {
                \Drupal::messenger()->addMessage(t('Please provide a valid metadata file.'),'error');
		    	return;
			}
			
			foreach($identity_providers as $key => $idp) {
				$saml_login_url = $idp->getLoginURL('HTTP-Redirect');
				if(empty($saml_login_url)) {
					$saml_login_url = $idp->getLoginURL('HTTP-POST');
				}
				$saml_issuer = $idp->getEntityID();
				$saml_x509_certificate = $idp->getSigningCertificate();
				$sp_issuer = $base_url;

                \Drupal::configFactory()->getEditable('miniorange_saml.settings')->set('miniorange_saml_sp_issuer', $sp_issuer)->save();
                \Drupal::configFactory()->getEditable('miniorange_saml.settings')->set('miniorange_saml_idp_issuer', $saml_issuer)->save();
                \Drupal::configFactory()->getEditable('miniorange_saml.settings')->set('miniorange_saml_idp_login_url', $saml_login_url)->save();
                \Drupal::configFactory()->getEditable('miniorange_saml.settings')->set('miniorange_saml_idp_x509_certificate', $saml_x509_certificate[0])->save();
			}
            \Drupal::messenger()->addMessage(t('Identity Provider Configuration successfully saved.'),'status');
			return;
		}else {
            \Drupal::messenger()->addMessage(t('Please provide a valid metadata file.'),'error');
		    return;
		}
    }
}